import { checkExceptions, createWaiter, WaiterState } from "@smithy/util-waiter";
import { DescribeLoadBalancersCommand, } from "../commands/DescribeLoadBalancersCommand";
const checkState = async (client, input) => {
    let reason;
    try {
        const result = await client.send(new DescribeLoadBalancersCommand(input));
        reason = result;
        return { state: WaiterState.SUCCESS, reason };
    }
    catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "LoadBalancerNotFoundException") {
            return { state: WaiterState.RETRY, reason };
        }
    }
    return { state: WaiterState.RETRY, reason };
};
export const waitForLoadBalancerExists = async (params, input) => {
    const serviceDefaults = { minDelay: 15, maxDelay: 120 };
    return createWaiter({ ...serviceDefaults, ...params }, input, checkState);
};
export const waitUntilLoadBalancerExists = async (params, input) => {
    const serviceDefaults = { minDelay: 15, maxDelay: 120 };
    const result = await createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    return checkExceptions(result);
};
