import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ElasticLoadBalancingV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ElasticLoadBalancingV2Client";
import { RemoveTrustStoreRevocationsInput, RemoveTrustStoreRevocationsOutput } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link RemoveTrustStoreRevocationsCommand}.
 */
export interface RemoveTrustStoreRevocationsCommandInput extends RemoveTrustStoreRevocationsInput {
}
/**
 * @public
 *
 * The output of {@link RemoveTrustStoreRevocationsCommand}.
 */
export interface RemoveTrustStoreRevocationsCommandOutput extends RemoveTrustStoreRevocationsOutput, __MetadataBearer {
}
declare const RemoveTrustStoreRevocationsCommand_base: {
    new (input: RemoveTrustStoreRevocationsCommandInput): import("@smithy/smithy-client").CommandImpl<RemoveTrustStoreRevocationsCommandInput, RemoveTrustStoreRevocationsCommandOutput, ElasticLoadBalancingV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: RemoveTrustStoreRevocationsCommandInput): import("@smithy/smithy-client").CommandImpl<RemoveTrustStoreRevocationsCommandInput, RemoveTrustStoreRevocationsCommandOutput, ElasticLoadBalancingV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Removes the specified revocation file from the specified trust store.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ElasticLoadBalancingV2Client, RemoveTrustStoreRevocationsCommand } from "@aws-sdk/client-elastic-load-balancing-v2"; // ES Modules import
 * // const { ElasticLoadBalancingV2Client, RemoveTrustStoreRevocationsCommand } = require("@aws-sdk/client-elastic-load-balancing-v2"); // CommonJS import
 * const client = new ElasticLoadBalancingV2Client(config);
 * const input = { // RemoveTrustStoreRevocationsInput
 *   TrustStoreArn: "STRING_VALUE", // required
 *   RevocationIds: [ // RevocationIds // required
 *     Number("long"),
 *   ],
 * };
 * const command = new RemoveTrustStoreRevocationsCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param RemoveTrustStoreRevocationsCommandInput - {@link RemoveTrustStoreRevocationsCommandInput}
 * @returns {@link RemoveTrustStoreRevocationsCommandOutput}
 * @see {@link RemoveTrustStoreRevocationsCommandInput} for command's `input` shape.
 * @see {@link RemoveTrustStoreRevocationsCommandOutput} for command's `response` shape.
 * @see {@link ElasticLoadBalancingV2ClientResolvedConfig | config} for ElasticLoadBalancingV2Client's `config` shape.
 *
 * @throws {@link RevocationIdNotFoundException} (client fault)
 *  <p>The specified revocation ID does not exist.</p>
 *
 * @throws {@link TrustStoreNotFoundException} (client fault)
 *  <p>The specified trust store does not exist.</p>
 *
 * @throws {@link ElasticLoadBalancingV2ServiceException}
 * <p>Base exception class for all service exceptions from ElasticLoadBalancingV2 service.</p>
 *
 *
 * @public
 */
export declare class RemoveTrustStoreRevocationsCommand extends RemoveTrustStoreRevocationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: RemoveTrustStoreRevocationsInput;
            output: {};
        };
        sdk: {
            input: RemoveTrustStoreRevocationsCommandInput;
            output: RemoveTrustStoreRevocationsCommandOutput;
        };
    };
}
